@@ -9,6 +9,7 @@ from functools import lru_cache
 from os.path import abspath, dirname
 # import awswrangler as wr
 from typing import Dict
+from black import FileMode, format_str
 
 import findspark
 import tomlkit
@@ -18,7 +19,7 @@ REQUIRED_PARAM = ["s3-staging-dir", "cluster-name", "stage", "region"]
 DEFAULT_TOML_PATH = "./pyproject.toml"
 
 DEFAULT_CONFIG_TEMPLATE = {
-    "cluster-name": "EDA",
+    "cluster-name": "cluster name",
     "s3-staging-dir": "s3://<bucket-name>/<your-staging-directory>",
     "stage": "dev",
     "date-time": "%Y-%m-%dT%H-%M-%S",
@@ -50,20 +51,20 @@ GIT_IGNORE_PATTERNS = [
 ]
 
 SIMPLE_KOALAS_EXAMPLE = """
-import sys
-import pandas as pd
-import numpy as np
-import databricks.koalas as ks
-from pyspark.sql import SparkSession
+try:
+    from pyspark import pandas as pd
+except:
+    import databricks.koalas as pd
 
-kdf = ks.DataFrame(
+kdf = pd.DataFrame(
 {'a': [1, 2, 3, 4, 5, 6],
  'b': [100, 200, 300, 400, 500, 600],
  'c': ["one", "two", "three", "four", "five", "six"]},
 index=[10, 20, 30, 40, 50, 60])
 
-print('Number of arguments:', len(sys.argv), 'arguments.')
+print('Number of arguments:', len(sys.argv) )
 print('Argument List:', str(sys.argv))
+print("N-rows", len(kdf))
 
 """.strip()
 
@@ -80,7 +81,6 @@ STDOUT_COLORS = dict(
     BOLD="\033[1m",
     UNDERLINE="\033[4m",
 )
-SH_DIR = "files/sh"
 
 
 def get_package_dir():
@@ -90,7 +90,7 @@ def get_package_dir():
 
 def get_static_files_dir():
     """Returns pyemr package path."""
-    return f'{get_package_dir()}/files'
+    return f"{get_package_dir()}/files"
 
 
 def get_mock_s3_path():
@@ -192,6 +192,9 @@ def get_project_attributes(keys: list):
       keys: list:
       keys: list:
       keys: list:
+      keys: list:
+      keys: list:
+      keys: list:
 
     Returns:
 
@@ -263,26 +266,20 @@ def get_project_name():
     return cinput("Project name", DEFAULT_CONFIG_TEMPLATE.get("name", "tmp"))
 
 
-def get_cluster_name(cluster_name: str = ""):
+def get_cluster_name(cluster_name: str = "default"):
     """Get cluster name.
 
     Args:
-      cluster_name: str:  (Default value = '')
-      cluster_name: str:  (Default value = "")
-      cluster_name: str:  (Default value = "")
-      cluster_name: str:  (Default value = "")
-      cluster_name: str:  (Default value = "")
-      cluster_name: str:  (Default value = "")
-      cluster_name: str:  (Default value = "")
-      cluster_name: str:  (Default value = "")
-      cluster_name: str:  (Default value = "")
-      cluster_name: str:  (Default value = "")
+      cluster_name: str:  (Default value = 'default')
+      cluster_name: str:  (Default value = "default")
+      cluster_name: str:  (Default value = "default")
+      cluster_name: str:  (Default value = "default")
 
     Returns:
 
     """
 
-    if cluster_name in ["", None, "None"]:
+    if cluster_name in ["", None, "None", "default"]:
         cluster_name = get_config_attr("cluster-name")
 
     return cluster_name
@@ -337,6 +334,9 @@ def get_project_type(toml_path: str = DEFAULT_TOML_PATH):
       toml_path: str:  (Default value = DEFAULT_TOML_PATH)
       toml_path: str:  (Default value = DEFAULT_TOML_PATH)
       toml_path: str:  (Default value = DEFAULT_TOML_PATH)
+      toml_path: str:  (Default value = DEFAULT_TOML_PATH)
+      toml_path: str:  (Default value = DEFAULT_TOML_PATH)
+      toml_path: str:  (Default value = DEFAULT_TOML_PATH)
 
     Returns:
 
@@ -361,6 +361,9 @@ def _pyproject_toml_exists(pyproj_path: str = DEFAULT_TOML_PATH):
       pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
       pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
       pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
 
     Returns:
 
@@ -382,6 +385,9 @@ def _get_pyproject_toml(pyproj_path: str = DEFAULT_TOML_PATH) -> Dict[str, str]:
       pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
       pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
       pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
 
     Returns:
       dict: Project toml param.
@@ -422,6 +428,12 @@ def _write_pyproject_toml(file_contents: dict, pyproj_path: str = DEFAULT_TOML_P
       pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
       file_contents: dict:
       pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
+      file_contents: dict:
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
+      file_contents: dict:
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
+      file_contents: dict:
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
 
     Returns:
 
@@ -552,9 +564,9 @@ def init_pyemr_param(cluster_name, s3_stage_dir, stage, region):
                 value = default_value
             tml["tool"]["pyemr"][variable_name] = value
 
-    print("[tool.pyemr]")
-    print(tomlkit.dumps(tml["tool"]["pyemr"]))
-
+    #print("[tool.pyemr]")
+    #print(tomlkit.dumps(tml["tool"]["pyemr"]))
+    
     _write_pyproject_toml(tml)
 
 
@@ -572,6 +584,9 @@ def add_dependencies(dependencies: list):
       dependencies: list:
       dependencies: list:
       dependencies: list:
+      dependencies: list:
+      dependencies: list:
+      dependencies: list:
 
     Returns:
 
@@ -633,10 +648,12 @@ def create_koalas_example(out_path):
 
     """
 
+    example_script = format_str(SIMPLE_KOALAS_EXAMPLE.strip(), mode=FileMode())
+
     path = f"{out_path}/script.py"
     if not os.path.isfile(path):
         with open(path, "w") as f:
-            f.write(SIMPLE_KOALAS_EXAMPLE.strip())
+            f.write(example_script)
 
 
 def add_main_package():
@@ -772,8 +789,8 @@ def get_new_spark_home():
 
 def set_spark_home():
     """Tries to set the correct spark home."""
+    os.environ["PYARROW_IGNORE_TIMEZONE"] = "1"
     os.environ["SPARK_HOME"] = get_new_spark_home()
-    print("SPARK_HOME=", os.environ["SPARK_HOME"])
     findspark.init()
 
 
