@@ -7,11 +7,10 @@ from functools import lru_cache
 import awswrangler as wr
 import boto3
 import pandas as pd
-from loguru import logger
 from tqdm import tqdm
 
 from .config import (
-    _pyproject_toml_exists, cprint, get_cluster_name, get_env_name, load_config,
+    _pyproject_toml_exists, cprint, get_cluster_name, get_env_name, load_config,color_text
 )
 
 
@@ -42,7 +41,7 @@ def cancel_emr_step(cluster_id, step_id):
         ClusterId=cluster_id,
         StepIds=[step_id],
     )
-    logger.info(f"Canceled step {step_id}")
+    cprint(f"Canceled step {step_id}")
     return response
 
 
@@ -75,23 +74,26 @@ def wait_else_cancel(cluster_id, step_id, description="Waiting"):
     Returns:
 
     """
-
+    colors = {"COMPLETED":'OKGREEN','FAILED':'FAIL'}
     last_state = None
     pbar = tqdm(
         yield_step_state(cluster_id, step_id, sleep=5),
-        desc=f"{description}:step_id={step_id},state=SUBMITTING",
+        desc= color_text(f"{description}:step_id={step_id},state=SUBMITTING", 'OKCYAN'),
     )
-
+    
     # wait for step to complete
     try:
         for state in pbar:
             if state != last_state:
-                pbar.set_description(f"{description}:step_id={step_id},state={state}")
-
+                color = colors.get(state,'OKCYAN')
+                pbar.set_description(color_text(f"{description}:step_id={step_id},state={state}", color))
+            
             last_state = state
             if state in ["COMPLETED", "FAILED"]:
                 break
     except KeyboardInterrupt:
+        color = colors.get('FAILED')
+        pbar.set_description(color_text(f"{description}:step_id={step_id},state=KeyboardInterrupt", color))
         cancel_emr_step(cluster_id, step_id)
 
 
@@ -111,6 +113,9 @@ def get_cluster_states(state_pattern: str):
       state_pattern: str:
       state_pattern: str:
       state_pattern: str:
+      state_pattern: str:
+      state_pattern: str:
+      state_pattern: str:
 
     Returns:
 
@@ -170,20 +175,14 @@ def get_clusters() -> dict:
 
 
 @lru_cache()
-def get_cluster_id(cluster_name: str = "") -> str:
+def get_cluster_id(cluster_name: str) -> str:
     """Returns the id of a cluster from its name. If no exact name match is found then a lower case is used.
 
     Args:
-      cluster_name: str: Cluster Name
-      cluster_name: str:  (Default value = '')
-      cluster_name: str:  (Default value = "")
-      cluster_name: str:  (Default value = "")
-      cluster_name: str:  (Default value = "")
-      cluster_name: str:  (Default value = "")
-      cluster_name: str:  (Default value = "")
-      cluster_name: str:  (Default value = "")
-      cluster_name: str:  (Default value = "")
-      cluster_name: str:  (Default value = "")
+      cluster_name: str
+      cluster_name: str:
+      cluster_name: str:
+      cluster_name: str:
 
     Returns:
       str: The id for cluster with name <cluster_name>
@@ -218,6 +217,7 @@ def describe_cluster(cluster_name):
 
     """
     client = boto3.client("emr")
+    cluster_name = get_cluster_name(cluster_name)
     cluster_id = get_cluster_id(cluster_name)
     cluster_desc = client.describe_cluster(ClusterId=cluster_id)
     return cluster_desc
@@ -233,6 +233,7 @@ def get_log_url(cluster_name):
       str: The s3 log path for the cluster.
 
     """
+    cluster_name = get_cluster_name(cluster_name)
     desc = describe_cluster(cluster_name)
     log_url = desc["Cluster"]["LogUri"]
     if log_url.endswith("/"):
@@ -276,15 +277,6 @@ def ssm_cluster(cluster_name: str):
       cluster_name: str:
       cluster_name: str:
       cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
 
     Returns:
 
@@ -339,7 +331,7 @@ def cancel_step(cluster_name, step_id, step_name_pattern, state_pattern):
     return response
 
 
-def list_steps(cluster_name, n, step_name_pattern, state_patterm) -> pd.DataFrame:
+def list_steps(cluster_name, n, step_name_pattern, state_patterm, print_info=False) -> pd.DataFrame:
     """List steps
 
     Args:
@@ -363,10 +355,11 @@ def list_steps(cluster_name, n, step_name_pattern, state_patterm) -> pd.DataFram
         else:
             step_name_pattern = "*"
 
-    print("")
-    cprint(
-        f"Steps on '{cluster_name}' matching name '{step_name_pattern}' in state '{state_patterm}'.",
-    )
+    if print_info:
+        print(
+            f"Steps on '{cluster_name}' matching name '{step_name_pattern}' in state '{state_patterm}'.",
+        )
+    
     cluster_id = get_cluster_id(cluster_name)
     client = boto3.client("emr")
     response = client.list_steps(ClusterId=cluster_id)
@@ -421,6 +414,7 @@ def get_last_submitted_step(cluster_name, name_pattern, state):
     )
 
 
+@lru_cache()
 def get_step_id(step_id: str, cluster_name: str, name_pattern: str, state: str):
     """Returns the latest step-id if step_id is none
 
@@ -437,47 +431,12 @@ def get_step_id(step_id: str, cluster_name: str, name_pattern: str, state: str):
       cluster_name: str:
       name_pattern: str:
       state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
 
     Returns:
 
     """
 
+    cluster_name = get_cluster_name(cluster_name)
     if step_id in [None, "", "latest", "None", "last"]:
         step_id = get_last_submitted_step(cluster_name, name_pattern, state)
 
