@@ -40,6 +40,6 @@ def launch_mock_python_venv():
 
 def launch_mock_python_docker():
     """Launch an interactive python session from inside docker. With mock s3."""
-    from pyemr.utils.docker import SH_DIR, docker_build_run
+    from pyemr.utils.docker import SH_DIR_DOCKER, docker_build_run
 
-    docker_build_run(f"{SH_DIR}/run_pyemr_python_mock.sh")
+    docker_build_run(f"{SH_DIR_DOCKER}/run_pyemr_python_mock.sh")
