@@ -1,16 +1,15 @@
+# pylint: skip-file
 import sys
-
 import pyspark
 
-
 print(sys.argv)
 
-
 uuid = sys.argv[1]
 out_path = sys.argv[2]
 
 sqlContext = pyspark.sql.SparkSession.builder.config(
-    "spark.sql.parquet.datetimeRebaseModeInWrite", "LEGACY",
+    "spark.sql.parquet.datetimeRebaseModeInWrite",
+    "LEGACY",
 ).getOrCreate()
 
 df = sqlContext.createDataFrame(
